@@ -73,7 +73,7 @@ sub include_rss {
         $content .= '<div class="feed">'
           .'<h3><a href="'.$entry->link.'">'
           .($entry->title||"no title").'</a></h3>'
-          .($entry->content->body||"")."</div>\n";
+          .($entry->summary->body||"")."</div>\n";
         return $content if $count==$entries;
     }
     return $content;
