@@ -5,6 +5,40 @@ use warnings;
 
 use parent qw/MojoMojo::Schema::Base::Result/;
 
+=head1 NAME
+
+MojoMojo::Schema::Result::PageVersion - Versioned page metadata
+
+=head1 DESCRIPTION
+
+This table implements versioning of page metadata (not content, see
+L<MojoMojo::Schema::Result::Content> for that). It has a composite
+primary key C<(page, version)>.
+
+When renaming a page, a new version is created in this table, with
+C<version> set to 1 + the maximum version for that C<page>. The
+C<status> of the new C<page_version> is set to "released", its 
+C<release_date> is set to C<< DateTime->now >>, while the old
+C<page_version>'s status is set to 'removed' and its C<remove_date>
+is set to C<< DateTime->now >>.
+
+=head2 TODO
+
+=over 4
+
+=item * document the relationships
+
+=item * in order to support proper rollback, meaning creating a new
+version for the rollback operation itself, a C<content_version>
+field needs to be added.
+
+=item * C<created> is apparently unused: set to 0 for pages populated when
+creating the database, and NULL for all normal pages.
+
+=back
+
+=cut
+
 __PACKAGE__->load_components( "Core" );
 __PACKAGE__->table("page_version");
 __PACKAGE__->add_columns(
@@ -22,26 +56,42 @@ __PACKAGE__->add_columns(
     "remove_date",           { data_type => "VARCHAR", is_nullable => 1, size => 100 },
     "comments",              { data_type => "TEXT",    is_nullable => 1, size => 4000 },
 
-    # FIXME: consider for 2 simple pages that both have only 1 revision, and there has been no
-    # making a second revision current. In the page_version table, some such pages have
-    # content_version_first and content_version_last (1, 1) and others (NULL, NULL)
+    # FIXME: in a wiki in which I had never rolled back a page (that is, never made a second
+    # revision current, I see in the page_version table that some pages have
+    # content_version_first and content_version_last (1, 1) and others (NULL, NULL). --dandv
     "content_version_first", { data_type => "INTEGER", is_nullable => 1, size => undef },
     "content_version_last",  { data_type => "INTEGER", is_nullable => 1, size => undef },
 );
-__PACKAGE__->set_primary_key( "version", "page" );
-__PACKAGE__->has_many( "pages", "MojoMojo::Schema::Result::Page",
-    { "foreign.id" => "self.page", "foreign.version" => "self.version" },
+__PACKAGE__->set_primary_key( "page", "version" );
+__PACKAGE__->has_many(
+    pages => "MojoMojo::Schema::Result::Page",
+    { 
+        "foreign.id" => "self.page", 
+        "foreign.version" => "self.version" 
+    },
 );
 __PACKAGE__->belongs_to( "creator", "MojoMojo::Schema::Result::Person", { id => "creator" } );
 __PACKAGE__->belongs_to( "page",    "MojoMojo::Schema::Result::Page",   { id => "page" }, );
-__PACKAGE__->belongs_to( "content", "MojoMojo::Schema::Result::Content",
-    { page => "page", version => "content_version_first" },
+__PACKAGE__->belongs_to(
+    content => "MojoMojo::Schema::Result::Content",
+    { 
+        page => "page",
+        version => "content_version_first" 
+    },
 );
-__PACKAGE__->belongs_to( "content", "MojoMojo::Schema::Result::Content",
-    { page => "page", version => "content_version_last" },
+__PACKAGE__->belongs_to(
+    content => "MojoMojo::Schema::Result::Content",
+    { 
+        page => "page", 
+        version => "content_version_last"
+    },
 );
-__PACKAGE__->belongs_to( "page_version", "MojoMojo::Schema::Result::PageVersion",
-    { page => "parent", version => "parent_version" },
+__PACKAGE__->belongs_to(
+    page_version => "MojoMojo::Schema::Result::PageVersion",
+    { 
+        page => "parent", 
+        version => "parent_version" 
+    },
 );
 __PACKAGE__->has_many(
     "page_versions",
@@ -52,9 +102,9 @@ __PACKAGE__->has_many(
     },
 );
 
-=head1 NAME
+=head1 METHODS
 
-MojoMojo::Schema::Result::PageVersion
+=cut
 
 =head1 AUTHOR
 
